PyTle
=====

.. currentmodule:: cysgp4

.. autoclass:: PyTle
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~PyTle.arg_perigee
      ~PyTle.bstar
      ~PyTle.catalog_number
      ~PyTle.eccentricity
      ~PyTle.epoch
      ~PyTle.inclination
      ~PyTle.int_designator
      ~PyTle.mean_anomaly
      ~PyTle.mean_motion
      ~PyTle.mean_motion_dt2
      ~PyTle.mean_motion_dt6
      ~PyTle.raan
      ~PyTle.rev_number

   .. rubric:: Methods Summary

   .. autosummary::

      ~PyTle.tle_strings

   .. rubric:: Attributes Documentation

   .. autoattribute:: arg_perigee
   .. autoattribute:: bstar
   .. autoattribute:: catalog_number
   .. autoattribute:: eccentricity
   .. autoattribute:: epoch
   .. autoattribute:: inclination
   .. autoattribute:: int_designator
   .. autoattribute:: mean_anomaly
   .. autoattribute:: mean_motion
   .. autoattribute:: mean_motion_dt2
   .. autoattribute:: mean_motion_dt6
   .. autoattribute:: raan
   .. autoattribute:: rev_number

   .. rubric:: Methods Documentation

   .. automethod:: tle_strings
